
local touchX -- where the display was last touched

local ball = Bitmap.new( Texture.new("ball.png") )
ball:setAnchorPoint(0.5, 0.5)
ball.angle = 0 -- current angle
ball.radii = {x = 80, y = 80} -- separate values so we can have ellipses (not just circles)
ball.origin = {x = 160, y = 240} -- origin on screen
ball.position = {x = 0, y = 0}
stage:addChild(ball)

function ball:update() -- update balls position on screen
  local cos, sin, degToRad = math.cos, math.sin, math.pi/180
  
  local a, o, r, p = self.angle, self.origin, self.radii, self.position
  
  local x = r.x * sin(a * degToRad) + o.x -- calculate new position
  local y = -r.y * cos(a * degToRad) + o.y
  
  self:setPosition(x, y) -- update on display

  p.x, p.y = x, y
end

local function onTouch(e) -- handle touch
  e:stopPropagation()
  touchX = e.touch.x -- only need to save x touch position
end

local function onDrag(e) -- handle drag
  e:stopPropagation()
  local tX = e.touch.x
  local dX = touchX - tX -- how much we moved our finger since last time
  touchX = tX  

  ball.angle = (ball.angle - dX) % 360 -- update ball
  ball:update()
end

stage:addEventListener(Event.TOUCHES_BEGIN, onTouch) -- touch event listeners
stage:addEventListener(Event.TOUCHES_MOVE, onDrag)

ball:update() -- start ball in correct position on display
